# Copyright (C) 2019 Majormode.  All rights reserved.
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


# Regular expression to match an email address compliant with RFC 5322
# (http://tools.ietf.org/html/rfc5322#section-3.4.1).  This regular
# expression has two parts: the part before the `@`, and the part
# after the `@`.  There are two alternatives for the part before the
# `@`: it can either consist of a series of letters, digits and
# certain symbols, including one or more dots.  However, dots may not
# appear consecutively or at the start or end of the email address.
# The other alternative requires the part before the `@` to be
# enclosed in double quotes, allowing any string of ASCII characters
# between the quotes.  Whitespace characters, double quotes and
# backslashes must be escaped with backslashes.
#
# The part after the `@` also has two alternatives.  It can either
# be a fully qualified domain name (e.g., `somehost.example.com`).
# The literal Internet address can either be an IP address, or a
# domain-specific routing address.  This regular expression omits the
# syntax using double quotes and square brackets, as RFC 2822 marks
# this notation as obsolete.
REGEX_PATTERN_EMAIL_ADDRESS = r"^[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?$"

REGEX_PATTERN_EMAIL_ADDRESS = r"""(?:[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*|"(?:[\x01-\x08\x0b\x0c\x0e-\x1f\x21\x23-\x5b\x5d-\x7f]|\\[\x01-\x09\x0b\x0c\x0e-\x7f])*")@(?:(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?|\[(?:(?:(2(5[0-5]|[0-4][0-9])|1[0-9][0-9]|[1-9]?[0-9]))\.){3}(?:(2(5[0-5]|[0-4][0-9])|1[0-9][0-9]|[1-9]?[0-9])|[a-z0-9-]*[a-z0-9]:(?:[\x01-\x08\x0b\x0c\x0e-\x1f\x21-\x5a\x53-\x7f]|\\[\x01-\x09\x0b\x0c\x0e-\x7f])+)\])"""

# Regular expression that matches an integer.
REGEX_PATTERN_INTEGER = r'\d+'

# Regular expression that matches an Internet Protocol version 4 (32-bit
# number).
REGEX_PATTERN_IPV4 = r'(\d{1,3}).(\d{1,3}).(\d{1,3}).(\d{1,3})'

# Regular expression that matches a Media Access Control (MAC) address.
#
# :note: This regular expression is generated with the following code:
#
#     ```python
#     r'^%s$' % '[.:-]{0,1}'.join([r'([0-9A-Za-z]{2})' for i in range(6)])
#     ```
REGEX_PATTERN_MAC_ADDRESS = r'([0-9A-Za-z]{2})[.:-]{0,1}([0-9A-Za-z]{2})[.:-]{0,1}([0-9A-Za-z]{2})[.:-]{0,1}([0-9A-Za-z]{2})[.:-]{0,1}([0-9A-Za-z]{2})[.:-]{0,1}([0-9A-Za-z]{2})'

# Regular expression that matches national and international phone
# numbers.
#
# The specification ITU-T E.123 requires that international phone
# numbers include a leading plus sign (known as the international prefix
# symbol), and allows only spaces to separate groups of digits.  Thanks
# to the international phone numbering plan (ITU-T E.164), phone numbers
# cannot contain more than 15 digits.
REGEX_PATTERN_PHONE_NUMBER = r'(([+][(]?[0-9]{1,3}[)]?)|([(]?[0-9]{4}[)]?))\s*[)]?[-\s\.]?[(]?[0-9]{1,3}[)]?([-\s\.]?[0-9]{3})([-\s\.]?[0-9]{3,4})'

# Regular expression that matches a Universally Unique Identifier (UUID).
REGEX_PATTERN_UUID = r'(?i)[\da-z]{8}-{0,1}[\da-z]{4}-{0,1}[\da-z]{4}-{0,1}[\da-z]{4}-{0,1}[\da-z]{12}'
